==> duckdb-0.9.1.tar.gz: duckdb-0.9.1/tools/pythonpkg/src/include/duckdb_python/import_cache/modules/datetime_module.hpp <==
//===----------------------------------------------------------------------===//
//                         DuckDB
//
// duckdb_python/import_cache/modules/datetime_module.hpp
//
//
//===----------------------------------------------------------------------===//

#pragma once

#include "duckdb_python/import_cache/python_import_cache_item.hpp"

namespace duckdb {

struct DatetimeDatetimeCacheItem : public PythonImportCacheItem {
public:
	static constexpr const char *Name = "datetime.datetime";

public:
	~DatetimeDatetimeCacheItem() override {
	}
	virtual void LoadSubtypes(PythonImportCache &cache) override {
		max.LoadAttribute("max", cache, *this);
		min.LoadAttribute("min", cache, *this);
	}

public:
	PythonImportCacheItem max;
	PythonImportCacheItem min;
};

struct DatetimeDateCacheItem : public PythonImportCacheItem {
public:
	static constexpr const char *Name = "datetime.date";

public:
	~DatetimeDateCacheItem() override {
	}
	virtual void LoadSubtypes(PythonImportCache &cache) override {
		max.LoadAttribute("max", cache, *this);
		min.LoadAttribute("min", cache, *this);
	}

public:
	PythonImportCacheItem max;
	PythonImportCacheItem min;
};

struct DatetimeCacheItem : public PythonImportCacheItem {
public:
	static constexpr const char *Name = "datetime";

public:
	~DatetimeCacheItem() override {
	}
	virtual void LoadSubtypes(PythonImportCache &cache) override {
		datetime.LoadAttribute("datetime", cache, *this);
		date.LoadAttribute("date", cache, *this);
		time.LoadAttribute("time", cache, *this);
		timedelta.LoadAttribute("timedelta", cache, *this);
	}

public:
	DatetimeDatetimeCacheItem datetime;
	DatetimeDateCacheItem date;
	PythonImportCacheItem time;
	PythonImportCacheItem timedelta;
};

} // namespace duckdb

==> duckdb-0.10.0.tar.gz: duckdb-0.10.0/tools/pythonpkg/src/include/duckdb_python/import_cache/modules/datetime_module.hpp <==

//===----------------------------------------------------------------------===//
//                         DuckDB
//
// duckdb_python/import_cache/modules/datetime_module.hpp
//
//
//===----------------------------------------------------------------------===//

#pragma once

#include "duckdb_python/import_cache/python_import_cache_item.hpp"

namespace duckdb {

struct DatetimeDatetimeCacheItem : public PythonImportCacheItem {

public:
	DatetimeDatetimeCacheItem(optional_ptr<PythonImportCacheItem> parent)
	    : PythonImportCacheItem("datetime", parent), min("min", this), max("max", this) {
	}
	~DatetimeDatetimeCacheItem() override {
	}

	PythonImportCacheItem min;
	PythonImportCacheItem max;
};

struct DatetimeDateCacheItem : public PythonImportCacheItem {

public:
	DatetimeDateCacheItem(optional_ptr<PythonImportCacheItem> parent)
	    : PythonImportCacheItem("date", parent), max("max", this), min("min", this) {
	}
	~DatetimeDateCacheItem() override {
	}

	PythonImportCacheItem max;
	PythonImportCacheItem min;
};

struct DatetimeCacheItem : public PythonImportCacheItem {

public:
	static constexpr const char *Name = "datetime";

public:
	DatetimeCacheItem()
	    : PythonImportCacheItem("datetime"), date(this), time("time", this), timedelta("timedelta", this),
	      datetime(this) {
	}
	~DatetimeCacheItem() override {
	}

	DatetimeDateCacheItem date;
	PythonImportCacheItem time;
	PythonImportCacheItem timedelta;
	DatetimeDatetimeCacheItem datetime;
};

} // namespace duckdb
